/*
------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------
************************************************ 601_Projekt_AVR_PB_LED ************************************************
------------------------------------------------------------------------------------------------------------------------
**************************************************** main.c ** V1.1 ****************************************************
------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------
 Demonstration der Taster und LEDs auf dem Testboard
 Zusaetzliche Header..: keine
 Module.(*.c und *.h).: application
 Benoetigte Hardware..: Testboard, Taster S1, S2, S3 und LED1, LED2, LED3
 Version..............: 1.1
 Compiler.............: CodeVisionAVR
 Chip.................: ATmega88
 Datum................: Juni 2009
 Autor................: Alwin Lenck (ALE23) basierend auf dem Projekt PB_LED von Udo Juerss
------------------------------------------------------------------------------------------------------------------------

Dieses Projekt stellt eine Applikation zur Demonstration der Taster (Pushbottons) und LEDs auf dem Testboard dar.
Die Taster sind nicht entprellt!

Die LED1 ist im Ruhezustand AUS und bei gedrueckter Taste S1 EIN
Die LED2 ist im Ruhezustand EIN und bei gedrueckter Taste S2 AUS
Die LED3 toggelt beim Betaetigen der Taste S3 von AUS nach EIN und umgekehrt

------------------------------------------------------------------------------------------------------------------------
In der Header-Datei application.h koennen die Definitionen fuer die Tasten und LEDs geaendert werden.
Die Definitionen sind hier wie folgt festgelegt:

Komponente:                    ATmega18-Pins:
*** LEDs
LED1                           PC2 (kann in application.h geaendert werden)
LED2                           PC3 (kann in application.h geaendert werden)
LED3                           PC4 (kann in application.h geaendert werden)

*** Taste
S1                             PB3 (kann in application.h geaendert werden)
S2                             PB4 (kann in application.h geaendert werden)
S3                             PB5 (kann in application.h geaendert werden)
*/
//----------------------------------------------------------------------------------------------------------------------
// Header-Dateien einfuegen:
//----------------------------------------------------------------------------------------------------------------------
#include "application.h"

//----------------------------------------------------------------------------------------------------------------------
// Globale Variablen:
//----------------------------------------------------------------------------------------------------------------------
U08 n;

//----------------------------------------------------------------------------------------------------------------------
//--Hauptprogramm main--------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
void main(void)
{
  // Setzen des System-Taktes (CPU-Clock), Ausschalten nicht benutzter Hardware-Module
  app_init();                                    // Initialisierung der Anwendung

  // Initialisieren der Tasten (Pushbuttons)
  S1_INIT();
  S2_INIT();
  S3_INIT();

  // Initialisieren der LEDs
  LED1_DDR |= LED1_BIT;                          // Setze LED1-Pin auf Ausgabe
  LED2_DDR |= LED2_BIT;                          // Setze LED2-Pin auf Ausgabe
  LED3_DDR |= LED3_BIT;                          // Setze LED3-Pin auf Ausgabe

  // Alle LEDs 3-mal aufleuchten lassen ("Lampen-Test")
  for (n = 3; n; n--)
  {
    LED1_PRT |= LED1_BIT;                        // LED1 auf EIN
    LED2_PRT |= LED2_BIT;                        // LED2 auf EIN
    LED3_PRT |= LED3_BIT;                        // LED3 auf EIN

    delay_ms(250);                               // 250 ms Verzoegerung (1/4 Sekunde)

    LED1_PRT &= ~LED1_BIT;                       // LED1 auf AUS
    LED2_PRT &= ~LED2_BIT;                       // LED2 auf AUS
    LED3_PRT &= ~LED3_BIT;                       // LED3 auf AUS

    delay_ms(200);                               // 200 ms Verzoegerung (1/5 Sekunde)
  }

//----------------------------------------------------------------------------------------------------------------------
// Hauptschleife:
//----------------------------------------------------------------------------------------------------------------------
  while (true)                                   // Endlosschleife
  {
    // Wenn Taste S1 gedrueckt wird, dann leuchtet LED1
    if (S1_PRESSED())
    {
      LED1_PRT |= LED1_BIT;                      // LED1 auf EIN
    }
    else
    {
      LED1_PRT &= ~LED1_BIT;                     // LED1 auf AUS
    }

    // Wenn Taste S2 gedrueckt wird, dann schaltet LED2 auf AUS
    if (S2_PRESSED())
    {
      LED2_PRT &= ~LED2_BIT;                     // LED2 auf AUS
    }
    else
    {
      LED2_PRT |= LED2_BIT;                      // LED2 auf EIN
    }

    // Wenn Taste S3 gedrueckt wird, dann toggle LED3 (EIN-AUS-EIN-AUS-...)
    if (S3_PRESSED())
    {
      LED3_PRT ^= LED3_BIT;                      // Toggle LED3

      S3_WAIT_NOT_PRESSED();                     // Warte bis Taste S3 losgelassen wird
    }
  }
}
//----------------------------------------------------------------------------------------------------------------------
